<?php
// Check Connection
add_action( 'wp_ajax_action_hr_office_connection', 'action_hr_office_connection_fn' );  
function action_hr_office_connection_fn() {
    // check this action is only performed by administrator role only.
    if( ! current_user_can('administrator') ){
      echo "You are not the admin!";
      wp_die();
    }
    // if nonce verification is failed then return the function
    if( ! wp_verify_nonce($_POST["api_checking_nonce"], 'api_checking_nonce') ){
      echo "Nonce Verification failed, Refresh the page! # ref: connection_098leksrgf";
      wp_die(); 
    }
    $portal_id = $_POST['portal_id'];
    $developer_key = $_POST['developer_key'];
    $language_id = $_POST['language_id'];
    $post_ID = $_POST['post_ID'];
    $appdata = [
      'portalId' => $portal_id,
      'developerKey' => $developer_key,
      'keywords' => '',
      'location' => '',
      'categoryId' => '',
      'educationLevelId' => '',
      'languageId' => $language_id,
    ];
    $client = new SoapClient("https://api.hroffice.nl/HROfficeCoreService.asmx?wsdl");        
    $resp = $client->GetAllJobByLanguage($appdata);


    if(isset($resp->GetAllJobByLanguageResult->Results->AvJobSearch->Id)){
        $resp_data_1 = $resp->GetAllJobByLanguageResult->Results->AvJobSearch->Id;        
    }
    elseif(isset($resp->GetAllJobByLanguageResult->Results->AvJobSearch[0])){
        $resp_data_1 = $resp->GetAllJobByLanguageResult->Results->AvJobSearch[0]->Id;        
    }else{
        $resp_data_1 = 0;        
    } 

    if($resp_data_1 != 0){
      echo 'Working';
      update_post_meta( $post_ID, '_api_connected_first_job_id', $resp_data_1 );
    }else{
      echo 'Not Working';
      update_post_meta( $post_ID, '_api_connected_first_job_id', '0' );
    }    
    wp_die(); 
}

// Load filters
add_action( 'wp_ajax_action_hr_office_filters_check', 'action_hr_office_filters_check_fn' );  
function action_hr_office_filters_check_fn() {
    if( ! current_user_can('administrator') ){
      echo "You are not the admin!";
      wp_die();
    }
    // if nonce verification is failed then return the function
    if( ! wp_verify_nonce( $_POST["hroffic_check_filters_nonce"], "hroffic_check_filters_nonce") ){
      echo "Nonce verification failed please refresh the page! ref: hr#offic#check:2103hhhh99ers#nonce ";
      wp_die();
    }
    $post_ID = $_POST['post_ID'];

    $portal_id = get_post_meta( $post_ID, '_api_portal_id', true );
    $developer_key = get_post_meta( $post_ID, '_api_developer_key', true );
    $language_id = get_post_meta( $post_ID, '_api_language_id', true );
    // check this action is only performed by administrator role only.
    $appdata = [
      'portalId' => $portal_id,
      'developerKey' => $developer_key,
      'keywords' => '',
      'location' => '',
      'categoryId' => '',
      'educationLevelId' => '',
      'languageId' => $language_id,
    ];
    $client = new SoapClient("https://api.hroffice.nl/HROfficeCoreService.asmx?wsdl");        
    $resp = $client->GetVacancyCustomFields($appdata);
    $resp_data = $resp->GetVacancyCustomFieldsResult->CustomFields->AvVacancyCustomField;
    ?> 

    <span class="prfx-row-title"><?php _e( 'Select filters you want to display on Vacancy list page', 'hr_office_vacancy_domain' )?></span>  
    <div class="prfx-row-content">      
    <?php
    $filter_array = array();
    if(get_post_meta( $post_ID, '_api_selected_filters', true )){
        $api_selected_filters = get_post_meta( $post_ID, '_api_selected_filters', true );
    }else{
        $api_selected_filters = [];
    }
    foreach ($resp_data as $value) {
      array_push($filter_array, $value->Name); 
    ?>
        <label for="meta-filters">
            <input type="checkbox" class="add_label_change_filter_dtl" name="meta_filters[]" <?php if(in_array($value->Name, $api_selected_filters)){echo 'checked';} ?> value="<?php echo $value->Name; ?>" />
            <?php echo $value->Name; ?>
        </label>
    <?php } ?>
    </div>    
  <?php  
  update_post_meta( $post_ID, '_api_filters_all', serialize($filter_array) );
  wp_die(); 
}


// Load Job Data
add_action( 'wp_ajax_action_hr_office_job_data_check', 'action_hr_office_job_data_check_fn' );  
function action_hr_office_job_data_check_fn() {
    // check this action is only performed by administrator role only.
    if( ! current_user_can('administrator') ){
      echo "You are not the admin!";
      wp_die();
    }
     // if nonce verification is failed then return the function
     if( ! wp_verify_nonce( $_POST["check_job_data_nonce"], "check_job_data_nonce") ){
      echo "Nonce verification failed please refresh the page! ref: #check:kjasdvhf087;#nonce ";
      wp_die();
    }
    $post_ID = $_POST['post_ID'];

    $portal_id = get_post_meta( $post_ID, '_api_portal_id', true );
    $developer_key = get_post_meta( $post_ID, '_api_developer_key', true );
    $language_id = get_post_meta( $post_ID, '_api_language_id', true );
    $connected_first_job_id = get_post_meta( $post_ID, '_api_connected_first_job_id', true );
    
    $appdata = [
      'portalId' => $portal_id,
      'developerKey' => $developer_key,
      'keywords' => '',
      'location' => '',
      'categoryId' => '',
      'educationLevelId' => '',
      'languageId' => $language_id,
    ];
    $client = new SoapClient("https://api.hroffice.nl/HROfficeCoreService.asmx?wsdl");        
    $resp = $client->GetAllJobByLanguage($appdata);
    $resp_data = $resp->GetAllJobByLanguageResult->Results->AvJobSearch;
    

    if(is_object($resp_data)){
        $resp_data_arr[0] = $resp_data;
    }else{
        $resp_data_arr = $resp_data;
    }
    ?> 

    <span class="prfx-row-title"><?php _e( 'Select Job data you want to display on Vacancy list page', 'hr_office_vacancy_domain' )?></span>  
    <div class="prfx-row-content">      
    <?php
    $jobdata_array = array();
    $job_category_list_array = array();
    if(get_post_meta( $post_ID, '_api_selected_job_data', true )){
        $api_selected_job_data = get_post_meta( $post_ID, '_api_selected_job_data', true );
    }else{
        $api_selected_job_data = [];
    }

    foreach ($resp_data_arr as $key => $value) {
      $reslt_array = (array)$value;      
      foreach ($reslt_array as $key_a => $value_a) {        
        if(!in_array($key_a, $jobdata_array, true)){
            array_push($jobdata_array, $key_a); 
        }
      }

      $categorylist_name = $reslt_array['CategoryList']->IdNamePair->Name;
      if(!in_array($categorylist_name, $job_category_list_array, true) && $categorylist_name != ''){
        array_push($job_category_list_array, $categorylist_name); 
      }
    }
    
        foreach ($jobdata_array as $key_j => $value_j) {  
    ?>
        <label for="meta_job_data">
            <input type="checkbox" class="add_label_change_job_listing" name="meta_job_data[]" <?php if(in_array($value_j, $api_selected_job_data)){echo 'checked';} ?> value="<?php echo $value_j; ?>" />
            <?php echo $value_j; ?>
        </label>
        <?php 
        } ?>
    </div>    
  <?php   
  update_post_meta( $post_ID, '_api_job_data_all', serialize($jobdata_array) );
  update_post_meta( $post_ID, '_api_job_data_category_list', serialize($job_category_list_array) );

  wp_die(); 
}

// Load Job Data for detail page
add_action( 'wp_ajax_action_hr_office_job_data_detailpage_check', 'action_hr_office_job_data_detailpage_check_fn' );  
function action_hr_office_job_data_detailpage_check_fn() {
    // check this action is only performed by administrator role only.
    if( ! current_user_can('administrator') ){
      echo "You are not the admin!";
      wp_die();
    }
    // if nonce verification is failed then return the function
    if( ! wp_verify_nonce( $_POST["check_job_data_detail_page_nonce"], "check_job_data_detail_page_nonce") ){
      echo "Nonce verification failed please refresh the page! ref: #check:job-data-deta,jb176251;#nonce ";
      wp_die();
    }
    $post_ID = $_POST['post_ID'];

    $portal_id = get_post_meta( $post_ID, '_api_portal_id', true );
    $developer_key = get_post_meta( $post_ID, '_api_developer_key', true );
    $language_id = get_post_meta( $post_ID, '_api_language_id', true );
    $connected_first_job_id = get_post_meta( $post_ID, '_api_connected_first_job_id', true );
    
    $appdata = [
      'portalId' => $portal_id,
      'developerKey' => $developer_key,
      'vacancyId' => $connected_first_job_id,
      'keywords' => '',
      'location' => '',
      'categoryId' => '',
      'educationLevelId' => '',
      'languageId' => $language_id,
    ];
    $client = new SoapClient("https://api.hroffice.nl/HROfficeCoreService.asmx?wsdl");        
    $resp = $client->GetJobByIdAndLanguage($appdata);
    $resp_data = (array)$resp->GetJobByIdAndLanguageResult
    ?> 

    <span class="prfx-row-title"><?php _e( 'Select Job data you want to Display on Sidebar of Vacancy Detail Page', 'hr_office_vacancy_domain' )?></span>  
    <div class="prfx-row-content">      
    <?php
    $jobdata_array = array();
    if(get_post_meta( $post_ID, '_api_selected_job_detail_page_data', true )){
        $api_selected_job_detail_page_data = get_post_meta( $post_ID, '_api_selected_job_detail_page_data', true );
    }else{
        $api_selected_job_detail_page_data = [];
    }

    foreach ($resp_data as $key => $value) {
      array_push($jobdata_array, $key); 
    ?>
        <label for="meta_job_data_detailpage">
            <input type="checkbox" class="add_label_change_jobdtl" name="meta_job_data_detailpage[]" <?php if(in_array($key, $api_selected_job_detail_page_data)){echo 'checked';} ?> value="<?php echo $key; ?>" />
            <?php echo $key; ?>
        </label>
    <?php } ?>
    </div>    
  <?php  
  update_post_meta( $post_ID, '_api_job_detail_data_all', serialize($jobdata_array) );
  wp_die(); 
}

// Load JobData Category List Image url
add_action( 'wp_ajax_action_hr_office_jobdata_category_list_image_check', 'action_hr_office_jobdata_category_list_image_check_fn' );  
function action_hr_office_jobdata_category_list_image_check_fn(){
    // check this action is only performed by administrator role only.
    if( ! current_user_can('administrator') ){
      echo "You are not the admin!";
      wp_die();
    }
    // if nonce verification is failed then return the function
    if( ! wp_verify_nonce( $_POST["check_category_list_img_nonce"], "check_category_list_img_nonce") ){
      echo "Nonce verification failed please refresh the page! ref: #check::categorylist0192271'nonce ";
      wp_die();
    }
    $post_ID = $_POST['post_ID'];

    $api_job_data_category_list = unserialize(get_post_meta( $post_ID, '_api_job_data_category_list', true ));
    $findonstring = array(" ","/");

    if($api_job_data_category_list):
        foreach ($api_job_data_category_list as $val_sall) { 
            $filter_meta_key = '_api_job_data_category_list_image_'.str_replace($findonstring, '_', $val_sall);
            $remove_style = '';
            $prfx_stored_meta = get_post_meta( $post_ID, $filter_meta_key, true );

            if($prfx_stored_meta){
               $attachment_image_url = wp_get_attachment_image_url($prfx_stored_meta, 'thumbnail');
            }else{
               $attachment_image_url = plugin_dir_url( __DIR__ ).'assets/img/blank-img.png';
               $remove_style = 'display:none';
            }
          ?>            
            <label for="meta-filters"> 
                <i><?php echo $val_sall; ?></i>               
                <input type="button" class="button upload_image_button" value="<?php _e( 'Select image', 'hr_office_vacancy_domain' ); ?>" data-att-id="<?php echo str_replace($findonstring, '_', $val_sall); ?>" />
                <input type="hidden" name="meta_jobdata_category_list_image_<?php echo str_replace($findonstring, '_', $val_sall); ?>" id="image_attachment_id_<?php echo str_replace($findonstring, '_', $val_sall); ?>" value="<?php if ( isset ( $prfx_stored_meta ) ) echo $prfx_stored_meta; ?>">                
                <img class="image_preview_div" id="image-preview-<?php echo str_replace($findonstring, '_', $val_sall); ?>" src="<?php echo $attachment_image_url; ?>" width="30" height="30" style="max-height: 30px; width: 30px;">
                <a href="#" class="remove-img-btn" id="remove-img-btn-<?php echo str_replace($findonstring, '_', $val_sall); ?>" style="<?php echo $remove_style; ?>" data-remove-img="<?php echo str_replace($findonstring, '_', $val_sall); ?>"><span class="dashicons dashicons-dismiss"></span></a>
             </label>    
    <?php
        } 
      endif; 
    ?>              
        <b class="notif-msg"><?php _e( 'Please select image with 1920×768 resolution', 'hr_office_vacancy_domain' ); ?></b>
    <?php
    wp_die(); 
}


// Check Referaal Tool Connection
add_action( 'wp_ajax_action_hr_office_referral_tool_connection', 'action_hr_office_referral_tool_connection_fn' );  
function action_hr_office_referral_tool_connection_fn() {
    // check this action is only performed by administrator role only.
    if( ! current_user_can('administrator') ){
      echo "You are not the admin!";
      wp_die();
    }
    // if nonce verification is failed then return the function
    if( ! wp_verify_nonce( $_POST["referral_tool_conn_nonce"], "referral_tool_conn_nonce") ){
      echo "Nonce verification failed please refresh the page! ref: #check::91263tool'nonce ";
      wp_die();
    }
    $referral_api_url = $_POST['referral_api_url'];
    $referral_api_key = $_POST['referral_api_key'];   

    $curl2 = curl_init();
        curl_setopt_array($curl2, array(
          CURLOPT_URL => $referral_api_url,
          CURLOPT_RETURNTRANSFER => true,
          CURLOPT_ENCODING => '',
          CURLOPT_MAXREDIRS => 10,
          CURLOPT_TIMEOUT => 0,
          CURLOPT_FOLLOWLOCATION => true,
          CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
          CURLOPT_CUSTOMREQUEST => 'POST',
          CURLOPT_SSL_VERIFYHOST => false,
          CURLOPT_SSL_VERIFYPEER => false,
          CURLOPT_POSTFIELDS =>'{
          "candidateId": "1234a-1234b-1234c-1234d",
          "code": "1234567",
          "vacancyId": "1234567890"
        }',
          CURLOPT_HTTPHEADER => array(
            'Content-Type: application/json',
            'Accept: text/plain',
            'X-Api-Key: '.$referral_api_key.'',
          ),
        ));

        $response = curl_exec($curl2);

        curl_close($curl2);
        
        $dataArray = json_decode($response, true);
        echo $dataArray['status'];      

    wp_die(); 
}