<?php
/**
 * Adds a meta box to the post editing screen
 */
function hr_office_prfx_custom_meta() {
  add_meta_box( 'hr_office_vacancy_meta', __( 'HROffice Vacancy Settings', 'hr_office_vacancy_domain' ), 'hr_office_vacancy_meta_callback', 'hroffice_vacn_shortc' );
  remove_meta_box('wpseo_meta', 'hroffice_vacn_shortc', 'normal');
  wp_enqueue_media();
}
add_action( 'add_meta_boxes', 'hr_office_prfx_custom_meta', 100 );

/**
 * Outputs the content of the meta box
 */
function hr_office_vacancy_meta_callback( $post ) {
  wp_nonce_field( basename( __FILE__ ), 'hr_office_vacancy_nonce' );
  $prfx_stored_meta = get_post_meta( $post->ID );

  $portal_id = get_post_meta( $post->ID, '_api_portal_id', true );
    $developer_key = get_post_meta( $post->ID, '_api_developer_key', true );
    $language_id = get_post_meta( $post->ID, '_api_language_id', true );
    // check this action is only performed by administrator role only.
    $appdata = [
      'portalId' => $portal_id,
      'developerKey' => $developer_key,
      'keywords' => '',
      'location' => '',
      'categoryId' => '',
      'educationLevelId' => '',
      'languageId' => $language_id,
    ];
    $client = new SoapClient("https://api.hroffice.nl/HROfficeCoreService.asmx?wsdl");        
    $resp = $client->GetVacancyCustomFields($appdata);
    $resp_data = $resp->GetVacancyCustomFieldsResult->CustomFields->AvVacancyCustomField;

  $referral_license_status = get_option( 'hr_office_vacancy_referral_license_status' );  
  ?>
<div class="tabs">
   <ul class="tabs-list">
      <li class="active"><a href="#tabs-1"><?php _e( 'API', 'hr_office_vacancy_domain' )?></a></li>
      <?php if ( isset( $prfx_stored_meta['_api_connected_first_job_id'] ) && $prfx_stored_meta['_api_connected_first_job_id'][0] != 0): ?>
      <li class="<?php if(get_post_meta( $post->ID, '_api_job_data_all', true ) == ''){echo 'hroffice-check-job-data';} ?>"><a href="#tabs-2"><?php _e( 'Listing Page', 'hr_office_vacancy_domain' )?></a></li>
      <li class="<?php if(get_post_meta( $post->ID, '_api_filters_all', true ) == ''){echo 'hroffice-check-filters';} ?>"><a href="#tabs-3"><?php _e( 'Filters', 'hr_office_vacancy_domain' )?></a></li>
      <li class="<?php if(get_post_meta( $post->ID, '_api_job_detail_data_all', true ) == ''){echo 'hroffice-check-job-data-detailpage';} ?>"><a href="#tabs-4"><?php _e( 'Detail Page', 'hr_office_vacancy_domain' )?></a></li>
      <li><a href="#tabs-5"><?php _e( 'Apply Form', 'hr_office_vacancy_domain' )?></a></li>
      <li><a href="#tabs-6"><?php _e( 'Appearance', 'hr_office_vacancy_domain' )?></a></li>
      <?php if($referral_license_status == 'included'): ?>
         <li><a href="#tabs-7"><?php _e( 'Referral', 'hr_office_vacancy_domain' )?></a></li>
      <?php endif; ?>
      <li><a href="#tabs-8"><?php _e( 'Job Alert Form', 'hr_office_vacancy_domain' )?></a></li>

      <?php endif; ?>
   </ul>
   <div id="tabs-1" class="tab active">
      <h4 class="tab-main-title"><?php _e( 'Manage API Settings', 'hr_office_vacancy_domain' )?></h4>
      <div class="tabs-content-area">
         <div class="hroffice-loader-connection hroffice-loader" style="display:none;"></div>
         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Portal ID', 'hr_office_vacancy_domain' )?></label>
            <input type="number" min="1" name="meta-text-portal-id" required value="<?php if ( isset ( $prfx_stored_meta['_api_portal_id'] ) ) echo $prfx_stored_meta['_api_portal_id'][0]; ?>" />
         </p>
         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Developer Key', 'hr_office_vacancy_domain' )?></label>
            <input type="text" name="meta-text-developer-key" required value="<?php if ( isset ( $prfx_stored_meta['_api_developer_key'] ) ) echo $prfx_stored_meta['_api_developer_key'][0]; ?>" />
         </p>
         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Language ID', 'hr_office_vacancy_domain' )?></label>      
            <select name="meta-text-language-id">
               <option value="1" <?php if ( isset ( $prfx_stored_meta['_api_language_id'] ) ) selected( $prfx_stored_meta['_api_language_id'][0], '1' ); ?>><?php _e('Dutch (1)', 'hr_office_vacancy_domain')?></option>
               <option value="2" <?php if ( isset ( $prfx_stored_meta['_api_language_id'] ) ) selected( $prfx_stored_meta['_api_language_id'][0], '2' ); ?>><?php _e('French (2)
                  ', 'hr_office_vacancy_domain' )?></option>
               <option value="3" <?php if ( isset ( $prfx_stored_meta['_api_language_id'] ) ) selected( $prfx_stored_meta['_api_language_id'][0], '3' ); ?>><?php _e('German (3)', 'hr_office_vacancy_domain' )?></option>
               <option value="4" <?php if ( isset ( $prfx_stored_meta['_api_language_id'] ) ) selected( $prfx_stored_meta['_api_language_id'][0], '4' ); ?>><?php _e('English (4)', 'hr_office_vacancy_domain' )?></option>
               <option value="5" <?php if ( isset ( $prfx_stored_meta['_api_language_id'] ) ) selected( $prfx_stored_meta['_api_language_id'][0], '5' ); ?>><?php _e('Italian (5)', 'hr_office_vacancy_domain' )?></option>
               <option value="6" <?php if ( isset ( $prfx_stored_meta['_api_language_id'] ) ) selected( $prfx_stored_meta['_api_language_id'][0], '6' ); ?>><?php _e('Polish (6)
                  ', 'hr_office_vacancy_domain' )?></option>
               <option value="7" <?php if ( isset ( $prfx_stored_meta['_api_language_id'] ) ) selected( $prfx_stored_meta['_api_language_id'][0], '7' ); ?>><?php _e('Spanish (7)', 'hr_office_vacancy_domain' )?></option>
            </select>
         </p>
         <p>
            <?php 
               if( isset( $prfx_stored_meta['_api_connected_first_job_id'] ) && $prfx_stored_meta['_api_connected_first_job_id'][0] != 0){       
                 $connection_txt = 'Working';
                 $connection_cls = 'connected';
               }else{        
                 $connection_txt = 'Not Working';
                 $connection_cls = 'notconnected';
               } ?>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'API Status', 'hr_office_vacancy_domain' )?></label>
            <span class="hroffice-connection-status <?php echo $connection_cls; ?>"><?php echo __($connection_txt, 'hr_office_vacancy_domain'); ?></span>
         </p>
         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Validate Credential', 'hr_office_vacancy_domain' )?></label>
            <button type="button" class="hroffice-check-connection button button-primary"><?php _e( 'Validate Credential', 'hr_office_vacancy_domain' )?></button>
            <input type="hidden" id="api_checking_nonce" name="api_checking_nonce" value="<?php echo wp_create_nonce("api_checking_nonce");
             ?>">
            <!-- <span class="hroffice-connection-status"></span> -->
         </p>
      </div>
   </div>
   <div id="tabs-2" class="tab">
      <?php if ( isset( $prfx_stored_meta['_api_connected_first_job_id'] ) && $prfx_stored_meta['_api_connected_first_job_id'][0] != 0): ?>
      <h4 class="tab-main-title"><?php _e( 'Manage Vacancy Listing Page', 'hr_office_vacancy_domain' )?></h4>
      <div class="tabs-content-area">
         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Check Job Data', 'hr_office_vacancy_domain' )?></label>
            <button type="button" class="hroffice-check-job-data button button-primary"><?php _e( 'Load / Refresh Job Data', 'hr_office_vacancy_domain' )?></button>
            <input type="hidden" id="check_job_data_nonce" name="check_job_data_nonce" value="<?php echo wp_create_nonce("check_job_data_nonce"); ?>" >
         </p>
         <div class="hroffice-loader-listing hroffice-loader" style="display:none;"></div>
         <div class="hroffice-listing-status">
            <?php 
               $api_job_data_all = unserialize(get_post_meta( get_the_ID(), '_api_job_data_all', true ));
               if(get_post_meta( get_the_ID(), '_api_selected_job_data', true )){
                 $api_selected_job_data = get_post_meta( get_the_ID(), '_api_selected_job_data', true );
               }else{
                 $api_selected_job_data = [];
               }
               if($api_job_data_all): ?>
            <span class="prfx-row-title"><?php _e( 'Select Job data you want to display on Vacancy list page', 'hr_office_vacancy_domain' )?></span>
            <div class="prfx-row-content">
               <?php
                  foreach ($api_job_data_all as $val_jall) { ?>      
               <label for="meta_job_data">
               <input type="checkbox" class="add_label_change_job_listing" name="meta_job_data[]" <?php if(in_array($val_jall, $api_selected_job_data)){echo 'checked';} ?> value="<?php echo $val_jall; ?>" /><?php echo $val_jall; ?>
               </label>
               <?php } ?>
            </div>
            <?php endif; ?>
         </div>
         <p class="wrap-select-box joblisting_data_label_change_div_area" <?php if(!$api_selected_job_data){echo 'style="display:none;"';} ?>>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Change Selected Vacancy Listing data Labels', 'hr_office_vacancy_domain' )?></label>                   
            <span class="prfx-row-content selected-filter-label slted-joblisting-label-div">
               <?php
               foreach ($api_selected_job_data as $val_sjldata) { 
               $selected_job_listing_data_meta_key = '_api_job_listing_data_label_'.$val_sjldata;
               ?>      
                  <label for="meta-filters" class="meta_job_listing_data_label_<?php echo $val_sjldata; ?>">                
                  <input type="text" name="meta_job_listing_data_label_<?php echo $val_sjldata; ?>" value="<?php if ( isset ( $prfx_stored_meta[$selected_job_listing_data_meta_key] ) ) echo $prfx_stored_meta[$selected_job_listing_data_meta_key][0]; ?>" />
                  <?php echo $val_sjldata; ?>
                  </label>
               <?php } ?>
            </span>
         </p>
         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'View Job Button Text', 'hr_office_vacancy_domain' )?></label>
            <input type="text" name="meta-text-list-view-job-button-text" value="<?php if( isset( $prfx_stored_meta['_list_view_job_button_text'] ) && $prfx_stored_meta['_list_view_job_button_text'][0]){echo $prfx_stored_meta['_list_view_job_button_text'][0];}else{echo 'View Job';} ?>" />
         </p>
         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Limit Number of Results', 'hr_office_vacancy_domain' )?></label>
            <input type="number" min="1" max="20" name="meta-text-limit-result" value="<?php if( isset( $prfx_stored_meta['_api_loadmore_limit'][0] ) && $prfx_stored_meta['_api_loadmore_limit'][0]){echo $prfx_stored_meta['_api_loadmore_limit'][0];}else{echo '10';} ?>" />
         </p>
         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Load More Button Text', 'hr_office_vacancy_domain' )?></label>
            <input type="text" name="meta-text-list-load-more-button-text" value="<?php if( isset( $prfx_stored_meta['_list_load_more_button_text'][0] ) && $prfx_stored_meta['_list_load_more_button_text'][0]){echo $prfx_stored_meta['_list_load_more_button_text'][0];}else{echo 'Load More';} ?>" />
         </p>
         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Select Vacancy Listing Page', 'hr_office_vacancy_domain' )?></label>
            <select name="meta-text-listing-page-select">
               <?php 
                  $allpages = get_pages( array('sort_column'=>'post_date', 'sort_order'=>'desc', 'post_type'=>'page', 'post_status'=>'publish', 'parent'=> 0) );          
                  foreach ( $allpages as $pagev ) { 
                  ?>
               <option value="<?php echo $pagev->ID; ?>" <?php if ( isset ( $prfx_stored_meta['_listing_page_selected'] ) ) selected( $prfx_stored_meta['_listing_page_selected'][0], $pagev->ID ); ?>><?php echo $pagev->post_title; ?></option>
               <?php
                  }
                  ?>         
            </select>
         </p>
         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Exclude Vacancy from Listing Page', 'hr_office_vacancy_domain' )?></label>
            <span class="inline-form-text">
               <input type="text" name="meta-text-list-exclude-vacancy-id" value="<?php if( isset( $prfx_stored_meta['_list_exclude_vacancy_id_text'][0] ) && $prfx_stored_meta['_list_exclude_vacancy_id_text'][0]){echo $prfx_stored_meta['_list_exclude_vacancy_id_text'][0];}else{echo '';} ?>" />
               <span class="sub-desc"><?php _e( 'Vacancy ID (comma seperated id if there is multiple)', 'hr_office_vacancy_domain' ); ?></span>
            </span>            
         </p>
         <p class="layout-selector">
            <span class="prfx-row-title"><?php _e( 'Select Vacancy Listing Page Layout', 'hr_office_vacancy_domain' )?></span> 
            <span class="cc-selector-2">
            <input id="visa2" type="radio" name="meta-radio-template-select" value="list" <?php if ( isset ( $prfx_stored_meta['_api_template_selected'] ) ) checked( $prfx_stored_meta['_api_template_selected'][0], 'list' ); ?> />
            <label class="drinkcard-cc visa" for="visa2" style="background-image:url('<?php echo plugin_dir_url( __DIR__ ); ?>assets/img/list-layout.jpg')"><?php _e( 'List Layout', 'hr_office_vacancy_domain' )?></label>
            <input id="mastercard2" type="radio" name="meta-radio-template-select" value="grid" <?php if ( isset ( $prfx_stored_meta['_api_template_selected'] ) ) checked( $prfx_stored_meta['_api_template_selected'][0], 'grid' ); ?> />
            <label class="drinkcard-cc mastercard" for="mastercard2" style="background-image:url('<?php echo plugin_dir_url( __DIR__ ); ?>assets/img/grid-layout.jpg')"><?php _e( 'Grid Layout', 'hr_office_vacancy_domain' )?></label>
            <input type="hidden" id="check_category_list_img_nonce" name="check_category_list_img_nonce" value="<?php echo wp_create_nonce('check_category_list_img_nonce');
             ?>" >
            </span>
         </p>         
         <p class="wrap-select-box jobdata_category_list_image_div_area" <?php if ( isset( $prfx_stored_meta['_api_template_selected'][0] ) && $prfx_stored_meta['_api_template_selected'][0] != 'grid'){ echo 'style="display:none;"'; }  ?> >
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Category image for Grid Layout', 'hr_office_vacancy_domain' )?></label>
            <span class="prfx-row-content selected-filter-label slted-category-list-image-div">
               <?php
                  $api_job_data_category_list = unserialize(get_post_meta( get_the_ID(), '_api_job_data_category_list', true ));
                  $findonstring = array(" ","/");

                  if($api_job_data_category_list):
                     foreach ($api_job_data_category_list as $val_sall) { 
                       $filter_meta_key = '_api_job_data_category_list_image_'.str_replace($findonstring, '_', $val_sall);
                       $remove_style = '';

                       if( isset( $prfx_stored_meta[$filter_meta_key][0] ) && $prfx_stored_meta[$filter_meta_key][0]){
                           $attachment_image_url = wp_get_attachment_image_url($prfx_stored_meta[$filter_meta_key][0], 'thumbnail');                           
                       }else{
                           $attachment_image_url = plugin_dir_url( __DIR__ ).'assets/img/blank-img.png';
                           $remove_style = 'display:none';
                       }
                  ?>                      

                     <label for="meta-filters">
                        <i><?php echo $val_sall; ?></i>                
                        <input type="button" class="button upload_image_button" value="<?php _e( 'Select image', 'hr_office_vacancy_domain' ); ?>" data-att-id="<?php echo str_replace($findonstring, '_', $val_sall); ?>" />
                        <input type="hidden" name="meta_jobdata_category_list_image_<?php echo str_replace($findonstring, '_', $val_sall); ?>" id="image_attachment_id_<?php echo str_replace($findonstring, '_', $val_sall); ?>" value="<?php if ( isset ( $prfx_stored_meta[$filter_meta_key] ) ) echo $prfx_stored_meta[$filter_meta_key][0]; ?>">                        
                        <img class="image_preview_div" id="image-preview-<?php echo str_replace($findonstring, '_', $val_sall); ?>" src="<?php echo $attachment_image_url; ?>" width="30" height="30" style="max-height: 30px; width: 30px;">
                        <a href="#" class="remove-img-btn" id="remove-img-btn-<?php echo str_replace($findonstring, '_', $val_sall); ?>" style="<?php echo $remove_style; ?>" data-remove-img="<?php echo str_replace($findonstring, '_', $val_sall); ?>"><span class="dashicons dashicons-dismiss"></span></a>
                     </label>
               <?php 
                     } 
                  endif;?>

                  <b class="notif-msg"><?php _e( 'Please select image with 1920×768 resolution', 'hr_office_vacancy_domain' ); ?></b>
            </span>
         </p>
         <div class="layout-editor">
            <span>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Vacancy Listing above Content', 'hr_office_vacancy_domain' )?></label>
            </span>
            <?php
               $id_wysiwyg = 'meta-textarea-listing-above-content';
               $job_listing_above_content = get_post_meta($post->ID, '_job_listing_above_content', true);
               $args_wysiwyg = array(
                       'media_buttons' => false, 
                       'textarea_name' => 'meta-textarea-listing-above-content', 
                       'textarea_rows' => 20, 
                       'quicktags' => true, 
                       'wpautop' => false,
                       'tinymce' => array(                  
                             'toolbar1'=> 'styleselect,bold,italic,underline,link,bullist,numlist,',
                       )
                   );
               wp_editor( $job_listing_above_content, $id_wysiwyg, $args_wysiwyg );
               ?>
         </div>
      </div>
      <?php else: ?>
      <p class="pls-connect">Please Connect the API first</p>
      <?php endif; ?> 
   </div>
   <div id="tabs-3" class="tab">
      <?php if ( isset( $prfx_stored_meta['_api_connected_first_job_id'] ) && $prfx_stored_meta['_api_connected_first_job_id'][0] != 0): ?> 
      <h4 class="tab-main-title"><?php _e( 'Manage Vacancy Listing Page Filters', 'hr_office_vacancy_domain' )?></h4>
      <div class="tabs-content-area">
         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Check Filters', 'hr_office_vacancy_domain' )?></label>
            <button type="button" class="hroffice-check-filters button button-primary"><?php _e( 'Load / Refresh Filters', 'hr_office_vacancy_domain' )?></button>
            <input type="hidden" id="hroffic_check_filters_nonce" name="hroffic_check_filters_nonce" value="<?php echo wp_create_nonce("hroffic_check_filters_nonce");
             ?>" >
         </p>
         <div class="hroffice-loader-filters hroffice-loader" style="display:none;"></div>
         <div class="hroffice-filters-status filter-Vacancy-list-page">
            <?php 
               $api_filters_all = unserialize(get_post_meta( get_the_ID(), '_api_filters_all', true ));
               if(get_post_meta( get_the_ID(), '_api_selected_filters', true )){
                 $api_selected_filters = get_post_meta( get_the_ID(), '_api_selected_filters', true );
               }else{
                 $api_selected_filters = [];
               }          
               if($api_filters_all): ?>
            <span class="prfx-row-title"><?php _e( 'Select filters you want to display on Vacancy list page', 'hr_office_vacancy_domain' )?></span>
            <div class="prfx-row-content">
               <?php
                  foreach ($api_filters_all as $val_fall) { ?>      
               <label for="meta-filters">
               <input type="checkbox" class="add_label_change_filter_dtl" name="meta_filters[]" <?php if(in_array($val_fall, $api_selected_filters)){echo 'checked';} ?> value="<?php echo $val_fall; ?>" /><?php echo $val_fall; ?>
               </label>
               <?php } ?>
            </div>
            <?php endif; ?>
         </div>
         <?php $nls_custom_settings = get_post_meta( get_the_ID(), 'nls_custom_url_settings', true ); ?>
         <p>
            <span class="prfx-row-title"><?php _e( 'URL Structure', 'hr_office_vacancy_domain' )?></span>
            <input type="checkbox" id="nls-enable-custom-url" name="nls-enable-custom-url" value="<?php echo ( 'yes' === $nls_custom_settings['nls_enable_custom_url_structure'] ) ? 'yes' : ''; ?>" <?php echo ( 'yes' === $nls_custom_settings['nls_enable_custom_url_structure'] ) ? 'checked="checked"' : ''; ?>   />
            <label for="nls-enable-custom-url">
               <?php _e('Enable custom url','hr_office_vacancy_domain'); ?>
            </label>
            <select style="<?php echo ( 'yes' === $nls_custom_settings['nls_enable_custom_url_structure'] ) ? '' : 'display:none;'; ?>" id="nls-select-custom-url-filter" name="nls-select-custom-url-filter" >
               <option value=""><?php _e('Select filter','hr_office_vacancy_domain'); ?></option>
               <?php if( ! empty( $resp_data ) ):
                  foreach ( $resp_data as $val_fall ) : ?>
                  <option <?php echo ( $nls_custom_settings['nls_selected_url_filter'] == $val_fall->Code ) ? 'selected="selected"' : ''; ?> value="<?php echo $val_fall->Code; ?>"><?php echo $val_fall->Name; ?></option>
               <?php endforeach;
                  endif; ?>
            </select>
         </p>
         
         <p class="wrap-select-box filter_data_label_change_div_area" <?php if(!$api_selected_filters){echo 'style="display:none;"';} ?>>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Change Selected Filters Labels', 'hr_office_vacancy_domain' )?></label>                   
            <span class="prfx-row-content selected-filter-label slted-filters-label-div">
               <?php
                  foreach ($api_selected_filters as $val_sall) { 
                    $filter_meta_key = '_api_filter_label_'.str_replace(' ', '_', $val_sall);
                  ?>      
               <label for="meta-filters" class="meta_filter_label_<?php echo str_replace(' ', '_', $val_sall); ?>">                
               <input type="text" name="meta_filter_label_<?php echo str_replace(' ', '_', $val_sall); ?>" value="<?php if ( isset ( $prfx_stored_meta[$filter_meta_key] ) ) echo $prfx_stored_meta[$filter_meta_key][0]; ?>" />
               <?php echo $val_sall; ?>
               </label>
               <?php } ?>
            </span>
         </p>
         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Filter Button Text', 'hr_office_vacancy_domain' )?></label>
            <input type="text" name="meta-text-list-filter-button-text" value="<?php if( isset( $prfx_stored_meta['_list_filter_button_text'][0]  ) && $prfx_stored_meta['_list_filter_button_text'][0]){echo $prfx_stored_meta['_list_filter_button_text'][0];}else{echo 'Filter';} ?>" />
         </p>
              
      </div>
      
      <?php else: ?>
      <p class="pls-connect">Please Connect the API first</p>
      <?php endif; ?>  
   </div>
   <div id="tabs-4" class="tab">
      <?php if ( isset( $prfx_stored_meta['_api_connected_first_job_id'] ) && $prfx_stored_meta['_api_connected_first_job_id'][0] != 0): ?> 
      <h4 class="tab-main-title"><?php _e( 'Manage Vacancy Detail Page', 'hr_office_vacancy_domain' )?></h4>
      <div class="tabs-content-area">
         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Check Job Data', 'hr_office_vacancy_domain' )?></label>
            <button type="button" class="hroffice-check-job-data-detailpage button button-primary"><?php _e( 'Load / Refresh Job Data', 'hr_office_vacancy_domain' )?></button>
            <input type="hidden" id="check_job_data_detail_page_nonce" name="check_job_data_detail_page_nonce" value="<?php echo wp_create_nonce('check_job_data_detail_page_nonce'); ?>">
         </p>
         <div class="hroffice-loader-job hroffice-loader" style="display:none;"></div>
         <div class="hroffice-job-detail-status">
            <?php 
               $api_job_data_all = unserialize(get_post_meta( get_the_ID(), '_api_job_detail_data_all', true ));
               if(get_post_meta( get_the_ID(), '_api_selected_job_detail_page_data', true )){
                 $api_selected_job_detail_page_data = get_post_meta( get_the_ID(), '_api_selected_job_detail_page_data', true );
               }else{
                 $api_selected_job_detail_page_data = [];
               }
               if($api_job_data_all): ?>
            <span class="prfx-row-title"><?php _e( 'Select Job data you want to Display on Sidebar of Vacancy Detail Page', 'hr_office_vacancy_domain' )?></span>
            <div class="prfx-row-content">
               <?php
                  foreach ($api_job_data_all as $val_jall) { ?>      
               <label for="meta_job_data_detailpage">
               <input type="checkbox" class="add_label_change_jobdtl" name="meta_job_data_detailpage[]" <?php if(in_array($val_jall, $api_selected_job_detail_page_data)){echo 'checked';} ?> value="<?php echo $val_jall; ?>" /><?php echo $val_jall; ?>
               </label>
               <?php } ?>
            </div>
            <?php endif; ?>
         </div>

         
         <p class="wrap-select-box jobdetail_data_label_change_div_area" <?php if(!$api_selected_job_detail_page_data){echo 'style="display:none;"';} ?>>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Change Selected Job data Labels for Sidebar', 'hr_office_vacancy_domain' )?></label>                   
            <span class="prfx-row-content selected-filter-label slted-jobdetail-label-div">
               <?php
               foreach ($api_selected_job_detail_page_data as $val_sjddall) { 
               $selected_jobdata_meta_key = '_api_job_detail_data_label_'.$val_sjddall;
               ?>      
                  <label for="meta-filters" class="meta_job_detail_data_label_<?php echo $val_sjddall; ?>">                
                  <input type="text" name="meta_job_detail_data_label_<?php echo $val_sjddall; ?>" value="<?php if ( isset ( $prfx_stored_meta[$selected_jobdata_meta_key] ) ) echo $prfx_stored_meta[$selected_jobdata_meta_key][0]; ?>" />
                  <?php echo $val_sjddall; ?>
                  </label>
               <?php } ?>
            </span>
         </p>
         <p class="jobdetail_data_category_image_div_area" <?php if( isset( $prfx_stored_meta['_api_template_selected'][0] ) && $prfx_stored_meta['_api_template_selected'][0] != 'grid'){ echo 'style="display:none;"'; } ?> >
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Show Category image in Top', 'hr_office_vacancy_domain' )?></label>
            <select name="meta_job_data_detailpage_top_category_image">
              <option value="no" <?php if ( isset ( $prfx_stored_meta['_job_data_detailpage_top_category_image'] ) ) selected( $prfx_stored_meta['_job_data_detailpage_top_category_image'][0], 'no' ); ?>><?php _e( 'No', 'hr_office_vacancy_domain' )?></option>  
              <option value="yes" <?php if ( isset ( $prfx_stored_meta['_job_data_detailpage_top_category_image'] ) ) selected( $prfx_stored_meta['_job_data_detailpage_top_category_image'][0], 'yes' ); ?>><?php _e( 'Yes', 'hr_office_vacancy_domain' )?></option>     
            </select>
         </p>

         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Job Apply button Text', 'hr_office_vacancy_domain' )?></label>
            <input type="text" name="meta-text-apply-button-text" value="<?php if( isset( $prfx_stored_meta['_job_apply_button_text'][0] ) && $prfx_stored_meta['_job_apply_button_text'][0]){echo $prfx_stored_meta['_job_apply_button_text'][0];}else{echo 'Apply';} ?>" />
         </p>
         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Back to Vacancy Link Text', 'hr_office_vacancy_domain' )?></label>
            <input type="text" name="meta-text-back-to-listing-text" value="<?php if( isset( $prfx_stored_meta['_job_data_back_to_listing_text'][0] ) && $prfx_stored_meta['_job_data_back_to_listing_text'][0]){echo $prfx_stored_meta['_job_data_back_to_listing_text'][0];}else{echo 'View all other Vacancies';} ?>" />
         </p>
         <div class="layout-editor">
            <span>
               <label for="meta-text" class="prfx-row-title"><?php _e( 'Job Detail Above Content', 'hr_office_vacancy_domain' )?></label>
            </span>
            <?php
               $id_wysiwyg = 'meta-text-jobdetail-above-content';
               $job_detail_above_content = get_post_meta($post->ID, '_job_detail_above_content', true);               
               $args_wysiwyg = array(
                       'media_buttons' => true, 
                       'textarea_name' => 'meta-text-jobdetail-above-content', 
                       'textarea_rows' => 40, 
                       'quicktags' => true, 
                       'wpautop' => false,
                       'tinymce' => array(                  
                             'toolbar1'=> 'styleselect,bold,italic,underline,link,bullist,numlist,',
                       )
                   );
               wp_editor( $job_detail_above_content, $id_wysiwyg, $args_wysiwyg );
               ?>
         </div>
         <div class="layout-editor">
            <span>
               <label for="meta-text" class="prfx-row-title"><?php _e( 'Job Detail Below Content', 'hr_office_vacancy_domain' )?></label>
            </span>
            <?php
               $id_wysiwyg = 'meta-text-jobdetail-below-content';
               $job_detail_below_content = get_post_meta($post->ID, '_job_detail_below_content', true);               
               $args_wysiwyg = array(
                       'media_buttons' => true, 
                       'textarea_name' => 'meta-text-jobdetail-below-content', 
                       'textarea_rows' => 40, 
                       'quicktags' => true, 
                       'wpautop' => false,
                       'tinymce' => array(                  
                             'toolbar1'=> 'styleselect,bold,italic,underline,link,bullist,numlist,',
                       )
                   );
               wp_editor( $job_detail_below_content, $id_wysiwyg, $args_wysiwyg );
               ?>
         </div>
         <div class="layout-editor">
            <span>
               <label for="meta-text" class="prfx-row-title"><?php _e( 'Sidebar Below Content', 'hr_office_vacancy_domain' )?></label>
            </span>
            <?php
               $id_wysiwyg = 'meta-text-jobdetail-sidebar-below-content';
               $jobdetail_sidebar_below_content = get_post_meta($post->ID, '_job_detail_sidebar_below_content', true);               
               $args_wysiwyg = array(
                       'media_buttons' => true, 
                       'textarea_name' => 'meta-text-jobdetail-sidebar-below-content', 
                       'textarea_rows' => 40, 
                       'quicktags' => true, 
                       'wpautop' => false,
                       'tinymce' => array(                  
                             'toolbar1'=> 'styleselect,bold,italic,underline,link,bullist,numlist,',
                       )
                   );
               wp_editor( $jobdetail_sidebar_below_content, $id_wysiwyg, $args_wysiwyg );
               ?>
         </div>

      </div>
      <?php else: ?>
      <p class="pls-connect">Please Connect the API first</p>
      <?php endif; ?>         
   </div>
   <div id="tabs-5" class="tab">
      <?php if ( isset( $prfx_stored_meta['_api_connected_first_job_id'] ) && $prfx_stored_meta['_api_connected_first_job_id'][0] != 0): ?>
      <h4 class="tab-main-title"><?php _e( 'Manage Vacancy Apply Form', 'hr_office_vacancy_domain' )?></h4>
      <div class="tabs-content-area">
         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Apply Form Title Text', 'hr_office_vacancy_domain' )?></label>
            <input type="text" name="meta-text-apply-form-title-text" value="<?php if ( isset( $prfx_stored_meta['_job_apply_form_title_text'][0] ) && $prfx_stored_meta['_job_apply_form_title_text'][0] ){ echo $prfx_stored_meta['_job_apply_form_title_text'][0]; }else{ echo 'Apply'; } ?>" />
         </p>         
         <p class="datainput-area">
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Max Upload Size', 'hr_office_vacancy_domain' )?></label>          
            <span class="inline-form-text">
            <input type="number" name="meta-text-apply-max-upload" min="1" max="30" value="<?php if ( isset( $prfx_stored_meta['_job_apply_max_upload'][0] ) && $prfx_stored_meta['_job_apply_max_upload'][0] ){ echo $prfx_stored_meta['_job_apply_max_upload'][0]; }else{ echo '10'; } ?>" /> MB 
            <span class="sub-desc"><?php _e( 'Upload Max Size: 30MB', 'hr_office_vacancy_domain' )?></span>
            </span>          
         </p>
         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Terms of Service Checkbox Text', 'hr_office_vacancy_domain' )?></label>
            <input type="text" name="meta-text-apply-terms-text" value="<?php if ( isset( $prfx_stored_meta['_job_apply_terms_text'][0] ) && $prfx_stored_meta['_job_apply_terms_text'][0]){ echo $prfx_stored_meta['_job_apply_terms_text'][0]; }else{ echo 'Lees meer over hoe wij met je privacy omgaan.'; }  ?>" />
         </p>
         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Privacy Policy Text', 'hr_office_vacancy_domain' )?></label>
            <input type="text" name="meta-text-privacy-policy-text" value="<?php if ( isset( $prfx_stored_meta['_job_apply_privacy_policy_text'][0] ) && $prfx_stored_meta['_job_apply_privacy_policy_text'][0] ){ echo $prfx_stored_meta['_job_apply_privacy_policy_text'][0]; }else{ echo 'Privacy Beleid'; } ?>" />
         </p>
         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Privacy Policy Link', 'hr_office_vacancy_domain' )?></label>        
            <select name="meta-text-privacy-policy-link">
               <?php foreach ( $allpages as $pagev ) { ?>
               <option value="<?php echo $pagev->ID; ?>" <?php if ( isset ( $prfx_stored_meta['_job_apply_privacy_policy_link'] ) ) selected( $prfx_stored_meta['_job_apply_privacy_policy_link'][0], $pagev->ID ); ?>><?php echo $pagev->post_title; ?></option>
               <?php
                  } ?>         
            </select>
         </p>  
         <p class="wrap-select-box">
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Form Validation Messages', 'hr_office_vacancy_domain' )?></label>                   
            <span class="prfx-row-content selected-filter-label">                     
               <label for="meta-filters">                
                  <input type="text" name="meta-text-apply-not-valid-formate-msg" value="<?php if ( isset( $prfx_stored_meta['_job_apply_not_valid_formate_msg'][0] ) && $prfx_stored_meta['_job_apply_not_valid_formate_msg'][0] ){ echo $prfx_stored_meta['_job_apply_not_valid_formate_msg'][0]; }else{ echo 'is not a valid Format'; } ?>"/><?php _e( 'is not a valid Format', 'hr_office_vacancy_domain' )?>                            
               </label> 
               <label for="meta-filters">
                  <input type="text" name="meta-text-apply-too-large-msg" value="<?php if ( isset( $prfx_stored_meta['_job_apply_too_large_msg'][0] ) && $prfx_stored_meta['_job_apply_too_large_msg'][0] ){ echo $prfx_stored_meta['_job_apply_too_large_msg'][0]; }else{ echo 'is too Large'; } ?>"/><?php _e( 'is too Large', 'hr_office_vacancy_domain' )?>  
               </label>
               <label for="meta-filters">
                  <input type="text" name="meta-text-apply-term-condition-msg" value="<?php if ( isset( $prfx_stored_meta['_job_apply_term_condition_msg'][0] ) &&  $prfx_stored_meta['_job_apply_term_condition_msg'][0] ){ echo $prfx_stored_meta['_job_apply_term_condition_msg'][0]; }else{ echo 'Please accept the Privacy Policy'; } ?>"/><?php _e( 'accept the Privacy Policy', 'hr_office_vacancy_domain' )?>  
               </label>              
            </span>
         </p>
         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Form Submit Button Text', 'hr_office_vacancy_domain' )?></label>
            <input type="text" name="meta-text-apply-form-submit-text" value="<?php if ( isset( $prfx_stored_meta['_job_apply_form_submit_text'][0] ) && $prfx_stored_meta['_job_apply_form_submit_text'][0] ){ echo $prfx_stored_meta['_job_apply_form_submit_text'][0]; }else{ echo 'Apply'; } ?>" />
         </p> 
         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Back to Vacancy Description Link Text', 'hr_office_vacancy_domain' )?></label>
            <input type="text" name="meta-text-apply-back-to-jobdetail-text" value="<?php if( isset( $prfx_stored_meta['_job_apply_back_to_jobdetail_text'][0] ) && $prfx_stored_meta['_job_apply_back_to_jobdetail_text'][0]){echo $prfx_stored_meta['_job_apply_back_to_jobdetail_text'][0];}else{echo 'Back to the job description';} ?>" />
         </p>      
         <div class="layout-editor">
            <span>
               <label for="meta-text" class="prfx-row-title"><?php _e( 'Thank you Page Text', 'hr_office_vacancy_domain' )?></label>
            </span>
            <?php
               $id_wysiwyg = 'meta-text-thankyou-page-text';
               $job_listing_above_content = get_post_meta($post->ID, '_job_apply_thankyou_page_text', true);
               if($job_listing_above_content){
                  $job_listing_above_content_dt = $job_listing_above_content;
               }else{
                  $job_listing_above_content_dt = "<h1>Thank you! The application has been sent.</h1><h2>We'll keep you informed.</h2>";
               }
               $args_wysiwyg = array(
                       'media_buttons' => false, 
                       'textarea_name' => 'meta-text-thankyou-page-text', 
                       'textarea_rows' => 40, 
                       'quicktags' => true, 
                       'wpautop' => false,
                       'tinymce' => array(                  
                             'toolbar1'=> 'styleselect,bold,italic,underline,link,bullist,numlist,',
                       )
                   );
               wp_editor( $job_listing_above_content_dt, $id_wysiwyg, $args_wysiwyg );
               ?>
         </div>
      </div>
      <?php else: ?>
      <p class="pls-connect">Please Connect the API first</p>
      <?php endif; ?>  
   </div>
   <div id="tabs-6" class="tab">
      <?php if ( isset( $prfx_stored_meta['_api_connected_first_job_id'][0] ) && $prfx_stored_meta['_api_connected_first_job_id'][0] != 0): ?>
      <h4 class="tab-main-title"><?php _e( 'Manage Appearance Settings', 'hr_office_vacancy_domain' )?></h4>
      <div class="tabs-content-area">
         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'List Page Job Title Size', 'hr_office_vacancy_domain' )?></label>      
            <select name="meta-select-list-job-title-size">               
               <option value="18" <?php if ( isset ( $prfx_stored_meta['_list_job_title_size'] ) ) selected( $prfx_stored_meta['_list_job_title_size'][0], '18' ); ?>><?php echo '18px'; ?></option>
               <option value="20" <?php if ( isset ( $prfx_stored_meta['_list_job_title_size'] ) ) selected( $prfx_stored_meta['_list_job_title_size'][0], '20' ); ?>><?php echo '20px'; ?></option>
               <option value="22" <?php if ( isset ( $prfx_stored_meta['_list_job_title_size'] ) ) selected( $prfx_stored_meta['_list_job_title_size'][0], '22' ); ?>><?php echo '22px'; ?></option>
               <option value="24" <?php if ( isset ( $prfx_stored_meta['_list_job_title_size'] ) ) selected( $prfx_stored_meta['_list_job_title_size'][0], '24' ); ?>><?php echo '24px'; ?></option>
               <option value="26" <?php if ( isset ( $prfx_stored_meta['_list_job_title_size'] ) ) selected( $prfx_stored_meta['_list_job_title_size'][0], '26' ); ?>><?php echo '26px'; ?></option>
               <option value="28" <?php if ( isset ( $prfx_stored_meta['_list_job_title_size'] ) ) selected( $prfx_stored_meta['_list_job_title_size'][0], '28' ); ?>><?php echo '28px'; ?></option>
               <option value="30" <?php if ( isset ( $prfx_stored_meta['_list_job_title_size'] ) ) selected( $prfx_stored_meta['_list_job_title_size'][0], '30' ); ?>><?php echo '30px'; ?></option>
               <option value="32" <?php if ( isset ( $prfx_stored_meta['_list_job_title_size'] ) ) selected( $prfx_stored_meta['_list_job_title_size'][0], '32' ); ?>><?php echo '32px'; ?></option>
               <option value="34" <?php if ( isset ( $prfx_stored_meta['_list_job_title_size'] ) ) selected( $prfx_stored_meta['_list_job_title_size'][0], '34' ); ?>><?php echo '34px'; ?></option>
               <option value="36" <?php if ( isset ( $prfx_stored_meta['_list_job_title_size'] ) ) selected( $prfx_stored_meta['_list_job_title_size'][0], '36' ); ?>><?php echo '36px'; ?></option>
            </select>
         </p>
         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'List Page Extra Data Size', 'hr_office_vacancy_domain' )?></label>      
            <select name="meta-select-list-job-otherdata-size">               
               <option value="16" <?php if ( isset ( $prfx_stored_meta['_list_job_other_data_size'] ) ) selected( $prfx_stored_meta['_list_job_other_data_size'][0], '16' ); ?>><?php echo '16px'; ?></option>
               <option value="18" <?php if ( isset ( $prfx_stored_meta['_list_job_other_data_size'] ) ) selected( $prfx_stored_meta['_list_job_other_data_size'][0], '18' ); ?>><?php echo '18px'; ?></option>
               <option value="20" <?php if ( isset ( $prfx_stored_meta['_list_job_other_data_size'] ) ) selected( $prfx_stored_meta['_list_job_other_data_size'][0], '20' ); ?>><?php echo '20px'; ?></option>
               <option value="22" <?php if ( isset ( $prfx_stored_meta['_list_job_other_data_size'] ) ) selected( $prfx_stored_meta['_list_job_other_data_size'][0], '22' ); ?>><?php echo '22px'; ?></option>
               <option value="24" <?php if ( isset ( $prfx_stored_meta['_list_job_other_data_size'] ) ) selected( $prfx_stored_meta['_list_job_other_data_size'][0], '24' ); ?>><?php echo '24px'; ?></option>
               <option value="26" <?php if ( isset ( $prfx_stored_meta['_list_job_other_data_size'] ) ) selected( $prfx_stored_meta['_list_job_other_data_size'][0], '26' ); ?>><?php echo '26px'; ?></option>
               <option value="28" <?php if ( isset ( $prfx_stored_meta['_list_job_other_data_size'] ) ) selected( $prfx_stored_meta['_list_job_other_data_size'][0], '28' ); ?>><?php echo '28px'; ?></option>
               <option value="30" <?php if ( isset ( $prfx_stored_meta['_list_job_other_data_size'] ) ) selected( $prfx_stored_meta['_list_job_other_data_size'][0], '30' ); ?>><?php echo '30px'; ?></option>
            </select>
         </p> 
         <p>
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Detail Page Job Title Size', 'hr_office_vacancy_domain' )?></label>      
            <select name="meta-select-detail-job-title-size">               
               <option value="32" <?php if ( isset ( $prfx_stored_meta['_detail_job_title_size'] ) ) selected( $prfx_stored_meta['_detail_job_title_size'][0], '32' ); ?>><?php echo '32px'; ?></option>
               <option value="34" <?php if ( isset ( $prfx_stored_meta['_detail_job_title_size'] ) ) selected( $prfx_stored_meta['_detail_job_title_size'][0], '34' ); ?>><?php echo '34px'; ?></option>
               <option value="36" <?php if ( isset ( $prfx_stored_meta['_detail_job_title_size'] ) ) selected( $prfx_stored_meta['_detail_job_title_size'][0], '36' ); ?>><?php echo '36px'; ?></option>
               <option value="38" <?php if ( isset ( $prfx_stored_meta['_detail_job_title_size'] ) ) selected( $prfx_stored_meta['_detail_job_title_size'][0], '38' ); ?>><?php echo '38px'; ?></option>
               <option value="40" <?php if ( isset ( $prfx_stored_meta['_detail_job_title_size'] ) ) selected( $prfx_stored_meta['_detail_job_title_size'][0], '40' ); ?>><?php echo '40px'; ?></option>
               <option value="42" <?php if ( isset ( $prfx_stored_meta['_detail_job_title_size'] ) ) selected( $prfx_stored_meta['_detail_job_title_size'][0], '42' ); ?>><?php echo '42px'; ?></option>
               <option value="44" <?php if ( isset ( $prfx_stored_meta['_detail_job_title_size'] ) ) selected( $prfx_stored_meta['_detail_job_title_size'][0], '44' ); ?>><?php echo '44px'; ?></option>
            </select>
         </p>
         <p>
            <label for="meta-color" class="prfx-row-title"><?php _e( 'Job Data Color', 'hr_office_vacancy_domain' )?></label>
            <input name="meta-color-list-job-title-color" type="text" value="<?php if ( isset ( $prfx_stored_meta['_list_job_title_color'] ) ) echo $prfx_stored_meta['_list_job_title_color'][0]; ?>" class="meta-color" />
         </p>
                 
         <p>
            <label for="meta-color" class="prfx-row-title"><?php _e( 'Button Text Color', 'hr_office_vacancy_domain' )?></label>
            <input name="meta-color-list-button-color" type="text" value="<?php if ( isset ( $prfx_stored_meta['_list_job_button_txt_color'] ) ) echo $prfx_stored_meta['_list_job_button_txt_color'][0]; ?>" class="meta-color" />
         </p>
         <p>
            <label for="meta-color" class="prfx-row-title"><?php _e( 'Button Background Color', 'hr_office_vacancy_domain' )?></label>
            <input name="meta-color-list-button-bg-color" type="text" value="<?php if ( isset ( $prfx_stored_meta['_list_job_button_bg_color'] ) ) echo $prfx_stored_meta['_list_job_button_bg_color'][0]; ?>" class="meta-color" />
         </p> 
         <p>
            <label for="meta-color" class="prfx-row-title"><?php _e( 'Job Listing Hover Color', 'hr_office_vacancy_domain' )?></label>
            <input name="meta-color-list-data-hover-color" type="text" value="<?php if ( isset ( $prfx_stored_meta['_list_job_data_hover_color'] ) ) echo $prfx_stored_meta['_list_job_data_hover_color'][0]; ?>" class="meta-color" />
         </p>
         <p>
            <label for="meta-color" class="prfx-row-title"><?php _e( 'Button Hover Color', 'hr_office_vacancy_domain' )?></label>
            <input name="meta-color-list-button-hover-color" type="text" value="<?php if ( isset ( $prfx_stored_meta['_list_job_button_hover_color'] ) ) echo $prfx_stored_meta['_list_job_button_hover_color'][0]; ?>" class="meta-color" />
         </p>        
      </div>
      <?php else: ?>
      <p class="pls-connect">Please Connect the API first</p>
      <?php endif; ?>  
   </div>

   <?php if($referral_license_status == 'included'): ?>
   <div id="tabs-7" class="tab">
      <?php if ( isset( $prfx_stored_meta['_api_connected_first_job_id'] ) && $prfx_stored_meta['_api_connected_first_job_id'][0] != 0): ?>
      <h4 class="tab-main-title"><?php _e( 'Manage Referral Tool Settings', 'hr_office_vacancy_domain' )?></h4>
      <div class="tabs-content-area">
         <p class="switch-button">
            <label for="meta-text" class="prfx-row-title"><?php _e( 'Referral Tool', 'hr_office_vacancy_domain' )?></label>            
            <label class="switch">
              <input type="checkbox" class="referral_tool_change_event" name="meta-referral-tool-status" <?php if ( $prfx_stored_meta['_job_apply_referral_tool_status'][0] == 'enabled' ){ echo 'checked'; } ?> value="enabled">
              <span class="slider round"></span>
            </label>
         </p> 
         <div class="hroffice-loader-referral-check hroffice-loader" style="display:none;"></div>
         
         <div class="referral_tool_other_settings" style="<?php if($prfx_stored_meta['_job_apply_referral_tool_status'][0] == 'disabled' ){ echo 'display: none;'; } ?>">
            <p>
               <label for="meta-text" class="prfx-row-title"><?php _e( 'Referral url Parameter', 'hr_office_vacancy_domain' )?></label>
               <input type="text" name="meta-text-referral-code-parameter" value="<?php if ( isset( $prfx_stored_meta['_job_apply_referral_code_parameter'][0] ) && $prfx_stored_meta['_job_apply_referral_code_parameter'][0] ){ echo $prfx_stored_meta['_job_apply_referral_code_parameter'][0]; }else{ echo 'ref'; } ?>" />
            </p>
            <p>
               <label for="meta-text" class="prfx-row-title"><?php _e( 'Referral Tool API url', 'hr_office_vacancy_domain' )?></label>
               <input type="text" name="meta-text-referral-api-url" value="<?php if ( isset( $prfx_stored_meta['_job_apply_referral_api_url'][0] ) && $prfx_stored_meta['_job_apply_referral_api_url'][0] ){ echo $prfx_stored_meta['_job_apply_referral_api_url'][0]; }else{ echo 'https://api-hroffice-staging.referraltool.nl/v1/candidate'; } ?>" />
            </p> 
            <p>
               <label for="meta-text" class="prfx-row-title"><?php _e( 'Referral Tool API Key', 'hr_office_vacancy_domain' )?></label>
               <input type="text" name="meta-text-referral-api-key" value="<?php if ( isset( $prfx_stored_meta['_job_apply_referral_api_key'][0] ) && $prfx_stored_meta['_job_apply_referral_api_key'][0] ){ echo $prfx_stored_meta['_job_apply_referral_api_key'][0]; }else{ echo ''; } ?>" />
               <button type="button" class="hroffice-check-referral-tool-connection button button-primary"><?php _e( 'Check API', 'hr_office_vacancy_domain' )?></button>
               <input type="hidden" id="referral_tool_conn_nonce" name="referral_tool_conn_nonce" value="<?php echo wp_create_nonce('referral_tool_conn_nonce'); ?>" >
               <span id="referral-tool-validation-icon" class="dashicons dashicons-yes-alt" style="display:none;"></span>
            </p> 
         </div>        
         
      </div>
      <?php else: ?>
      <p class="pls-connect">Please Connect the API first</p>
      <?php endif; ?>  
   </div>
   <?php endif; ?>

   <div id="tabs-8" class="tab">
      <?php if ( isset( $prfx_stored_meta['_api_connected_first_job_id'] ) && $prfx_stored_meta['_api_connected_first_job_id'][0] != 0): ?>
      <h4 class="tab-main-title"><?php _e( 'Manage Job Alert Form', 'hr_office_vacancy_domain' )?></h4>
      <div class="tabs-content-area"> 
            <p>
               <label for="meta-text" class="prfx-row-title"><?php _e( 'ShortCode for Display Job Alert Form', 'hr_office_vacancy_domain' )?></label>
               <span class="sub-desc-bold">[hroffice-job-alert id="<?php echo $post->ID; ?>"]</span>
            </p>
            <p>
               <label for="meta-text" class="prfx-row-title"><?php _e( 'First Name Label', 'hr_office_vacancy_domain' )?></label>
               <input type="text" name="meta-text-jobalert-fname-label" value="<?php if ( isset( $prfx_stored_meta['_jobalert_form_fname_label'][0] ) && $prfx_stored_meta['_jobalert_form_fname_label'][0] ){ echo $prfx_stored_meta['_jobalert_form_fname_label'][0]; }else{ echo 'First Name'; } ?>" />
            </p>
            <p>
               <label for="meta-text" class="prfx-row-title"><?php _e( 'Last Name Label', 'hr_office_vacancy_domain' )?></label>
               <input type="text" name="meta-text-jobalert-lname-label" value="<?php if ( isset( $prfx_stored_meta['_jobalert_form_lname_label'][0] ) && $prfx_stored_meta['_jobalert_form_lname_label'][0] ){ echo $prfx_stored_meta['_jobalert_form_lname_label'][0]; }else{ echo 'Last Name'; } ?>" />
            </p> 
            <p>
               <label for="meta-text" class="prfx-row-title"><?php _e( 'Email Label', 'hr_office_vacancy_domain' )?></label>
               <input type="text" name="meta-text-jobalert-email-label" value="<?php if ( isset( $prfx_stored_meta['_jobalert_form_email_label'][0] ) && $prfx_stored_meta['_jobalert_form_email_label'][0] ){ echo $prfx_stored_meta['_jobalert_form_email_label'][0]; }else{ echo 'Email'; } ?>" />
            </p> 
            <p>
               <label for="meta-text" class="prfx-row-title"><?php _e( 'Discipline Options Label', 'hr_office_vacancy_domain' )?></label>
               <input type="text" name="meta-text-jobalert-discipline-label" value="<?php if ( isset( $prfx_stored_meta['_jobalert_form_discipline_label'][0] ) && $prfx_stored_meta['_jobalert_form_discipline_label'][0] ){ echo $prfx_stored_meta['_jobalert_form_discipline_label'][0]; }else{ echo 'Discipline'; } ?>" />
            </p>
            <p>
               <label for="meta-text" class="prfx-row-title"><?php _e( 'Submit Button Text', 'hr_office_vacancy_domain' )?></label>
               <input type="text" name="meta-text-jobalert-submit-label" value="<?php if ( isset( $prfx_stored_meta['_jobalert_form_submit_label'][0] ) && $prfx_stored_meta['_jobalert_form_submit_label'][0] ){ echo $prfx_stored_meta['_jobalert_form_submit_label'][0]; }else{ echo 'Register'; } ?>" />
            </p>
            <div class="layout-editor">
               <span>
                  <label for="meta-text" class="prfx-row-title"><?php _e( 'Form Above Content', 'hr_office_vacancy_domain' )?></label>
               </span>
               <?php
                  $id_wysiwyg = 'meta-text-jobalert-above-content';
                  $jobalert_form_above_content = get_post_meta($post->ID, '_jobalert_form_above_content', true);
                  if($jobalert_form_above_content){
                     $jobalert_form_above_content_dt = $jobalert_form_above_content;
                  }else{
                     $jobalert_form_above_content_dt = "";
                  }
                  $args_wysiwyg = array(
                          'media_buttons' => false, 
                          'textarea_name' => 'meta-text-jobalert-above-content', 
                          'textarea_rows' => 40, 
                          'quicktags' => true, 
                          'wpautop' => false,
                          'tinymce' => array(                  
                                'toolbar1'=> 'styleselect,bold,italic,underline,link,bullist,numlist,',
                          )
                      );
                  wp_editor( $jobalert_form_above_content_dt, $id_wysiwyg, $args_wysiwyg );
                  ?>
            </div>
      </div>
      <?php else: ?>
      <p class="pls-connect">Please Connect the API first</p>
      <?php endif; ?>  
   </div>

</div>
<div class="shortcode-div-content">
   <?php if( isset( $prfx_stored_meta['_api_connected_first_job_id'] ) && $prfx_stored_meta['_api_connected_first_job_id'][0] != 0): ?>
   <p><b><?php _e( 'ShortCode for Display Vacancy Listing in Page', 'hr_office_vacancy_domain' )?>:</b> [hroffice-vacancy id="<?php echo $post->ID; ?>"]</p>
   <?php endif; ?>
</div>

  <?php
}


/**
 * Saves the custom meta input
 */
function hr_office_vacancy_meta_save( $post_id ) {
 
  // Checks save status
  $is_autosave = wp_is_post_autosave( $post_id );
  $is_revision = wp_is_post_revision( $post_id );
  $is_valid_nonce = ( isset( $_POST[ 'hr_office_vacancy_nonce' ] ) && wp_verify_nonce( $_POST[ 'hr_office_vacancy_nonce' ], basename( __FILE__ ) ) ) ? 'true' : 'false';
 
  // Exits script depending on save status
  if ( $is_autosave || $is_revision || !$is_valid_nonce ) {
    return;
  }
 
  // Checks for input and sanitizes/saves if needed
  if( isset( $_POST[ 'meta-text-portal-id' ] ) ) {
    update_post_meta( $post_id, '_api_portal_id', sanitize_text_field( $_POST[ 'meta-text-portal-id' ] ) );
  }
  if( isset( $_POST[ 'meta-text-developer-key' ] ) ) {
    update_post_meta( $post_id, '_api_developer_key', sanitize_text_field( $_POST[ 'meta-text-developer-key' ] ) );
  }
  if( isset( $_POST[ 'meta-text-language-id' ] ) ) {
    update_post_meta( $post_id, '_api_language_id', sanitize_text_field( $_POST[ 'meta-text-language-id' ] ) );
  }

  if( isset( $_POST[ 'meta_filters' ] ) ) {
    update_post_meta( $post_id, '_api_selected_filters', $_POST[ 'meta_filters' ] );
  }else{
    update_post_meta( $post_id, '_api_selected_filters', '' );
  }

  if( isset( $_POST[ 'meta_job_data' ] ) ) {
    update_post_meta( $post_id, '_api_selected_job_data', $_POST[ 'meta_job_data' ] );
  }else{
    update_post_meta( $post_id, '_api_selected_job_data', '' );
  }

  if( isset( $_POST[ 'meta-text-limit-result' ] ) ) {
    update_post_meta( $post_id, '_api_loadmore_limit', sanitize_text_field( $_POST[ 'meta-text-limit-result' ] ) );
  }
  if( isset( $_POST[ 'meta-radio-template-select' ] ) ) {
    update_post_meta( $post_id, '_api_template_selected', sanitize_text_field( $_POST[ 'meta-radio-template-select' ] ) );
  }else{
    update_post_meta( $post_id, '_api_template_selected', 'list' );
  }

  if( isset( $_POST[ 'meta_job_data_detailpage' ] ) ) {
    update_post_meta( $post_id, '_api_selected_job_detail_page_data', $_POST[ 'meta_job_data_detailpage' ] );
  }else{
    update_post_meta( $post_id, '_api_selected_job_detail_page_data', '' );
  }

  if( isset( $_POST[ 'meta-text-list-exclude-vacancy-id' ] ) ) {
    update_post_meta( $post_id, '_list_exclude_vacancy_id_text', sanitize_text_field( $_POST[ 'meta-text-list-exclude-vacancy-id' ] ) );
  }

  if( isset( $_POST[ 'meta-select-list-job-title-size' ] ) ) {
    update_post_meta( $post_id, '_list_job_title_size', sanitize_text_field( $_POST[ 'meta-select-list-job-title-size' ] ) );
  }
  if( isset( $_POST[ 'meta-color-list-job-title-color' ] ) ) {
    update_post_meta( $post_id, '_list_job_title_color', sanitize_text_field( $_POST[ 'meta-color-list-job-title-color' ] ) );
  }
  if( isset( $_POST[ 'meta-select-list-job-otherdata-size' ] ) ) {
    update_post_meta( $post_id, '_list_job_other_data_size', sanitize_text_field( $_POST[ 'meta-select-list-job-otherdata-size' ] ) );
  }    
  if( isset( $_POST[ 'meta-color-list-button-color' ] ) ) {
    update_post_meta( $post_id, '_list_job_button_txt_color', sanitize_text_field( $_POST[ 'meta-color-list-button-color' ] ) );
  }  
  if( isset( $_POST[ 'meta-select-detail-job-title-size' ] ) ) {
    update_post_meta( $post_id, '_detail_job_title_size', sanitize_text_field( $_POST[ 'meta-select-detail-job-title-size' ] ) );
  }  
  if( isset( $_POST[ 'meta-color-list-button-bg-color' ] ) ) {
    update_post_meta( $post_id, '_list_job_button_bg_color', sanitize_text_field( $_POST[ 'meta-color-list-button-bg-color' ] ) );
  }
    
  if( isset( $_POST[ 'meta-text-apply-max-upload' ] ) ) {
    update_post_meta( $post_id, '_job_apply_max_upload', sanitize_text_field( $_POST[ 'meta-text-apply-max-upload' ] ) );
  }  
  if( isset( $_POST[ 'meta-text-apply-terms-text' ] ) ) {
    update_post_meta( $post_id, '_job_apply_terms_text', $_POST[ 'meta-text-apply-terms-text' ]);
  }
  if( isset( $_POST[ 'meta-textarea-listing-above-content' ] ) ) {
    update_post_meta( $post_id, '_job_listing_above_content', $_POST[ 'meta-textarea-listing-above-content' ] );
  }  
  if( isset( $_POST[ 'meta-text-apply-button-text' ] ) ) {
    update_post_meta( $post_id, '_job_apply_button_text', sanitize_text_field( $_POST[ 'meta-text-apply-button-text' ] ) );
  }  
  if( isset( $_POST[ 'meta-text-privacy-policy-text' ] ) ) {
    update_post_meta( $post_id, '_job_apply_privacy_policy_text', sanitize_text_field( $_POST[ 'meta-text-privacy-policy-text' ] ) );
  }  
  if( isset( $_POST[ 'meta-text-privacy-policy-link' ] ) ) {
    update_post_meta( $post_id, '_job_apply_privacy_policy_link', sanitize_text_field( $_POST[ 'meta-text-privacy-policy-link' ] ) );
  }  
  if( isset( $_POST[ 'meta-text-thankyou-page-text' ] ) ) {
    update_post_meta( $post_id, '_job_apply_thankyou_page_text', $_POST[ 'meta-text-thankyou-page-text' ] );
  }
  if( isset( $_POST[ 'meta-text-apply-not-valid-formate-msg' ] ) ) {
    update_post_meta( $post_id, '_job_apply_not_valid_formate_msg', sanitize_text_field( $_POST[ 'meta-text-apply-not-valid-formate-msg' ] ) );
  }
  if( isset( $_POST[ 'meta-text-apply-too-large-msg' ] ) ) {
    update_post_meta( $post_id, '_job_apply_too_large_msg', sanitize_text_field( $_POST[ 'meta-text-apply-too-large-msg' ] ) );
  }
  if( isset( $_POST[ 'meta-text-apply-form-title-text' ] ) ) {
    update_post_meta( $post_id, '_job_apply_form_title_text', sanitize_text_field( $_POST[ 'meta-text-apply-form-title-text' ] ) );
  }
  if( isset( $_POST[ 'meta-text-apply-form-submit-text' ] ) ) {
    update_post_meta( $post_id, '_job_apply_form_submit_text', sanitize_text_field( $_POST[ 'meta-text-apply-form-submit-text' ] ) );
  }
  if( isset( $_POST[ 'meta-text-list-view-job-button-text' ] ) ) {
    update_post_meta( $post_id, '_list_view_job_button_text', sanitize_text_field( $_POST[ 'meta-text-list-view-job-button-text' ] ) );
  }
  if( isset( $_POST[ 'meta-text-list-load-more-button-text' ] ) ) {
    update_post_meta( $post_id, '_list_load_more_button_text', sanitize_text_field( $_POST[ 'meta-text-list-load-more-button-text' ] ) );
  }
  if( isset( $_POST[ 'meta-text-list-filter-button-text' ] ) ) {
    update_post_meta( $post_id, '_list_filter_button_text', sanitize_text_field( $_POST[ 'meta-text-list-filter-button-text' ] ) );
  }
  if( isset( $_POST[ 'meta-color-list-data-hover-color' ] ) ) {
    update_post_meta( $post_id, '_list_job_data_hover_color', sanitize_text_field( $_POST[ 'meta-color-list-data-hover-color' ] ) );
  }
  if( isset( $_POST[ 'meta-color-list-button-hover-color' ] ) ) {
    update_post_meta( $post_id, '_list_job_button_hover_color', sanitize_text_field( $_POST[ 'meta-color-list-button-hover-color' ] ) );
  }
  if( isset( $_POST[ 'meta-text-apply-term-condition-msg' ] ) ) {
    update_post_meta( $post_id, '_job_apply_term_condition_msg', sanitize_text_field( $_POST[ 'meta-text-apply-term-condition-msg' ] ) );
  }
  if( isset( $_POST[ 'meta_job_data_detailpage_top_category_image' ] ) ) {
    update_post_meta( $post_id, '_job_data_detailpage_top_category_image', sanitize_text_field( $_POST[ 'meta_job_data_detailpage_top_category_image' ] ) );
  }
  if( isset($_POST['meta-radio-template-select']) && $_POST['meta-radio-template-select'] == 'list' ){
    update_post_meta( $post_id, '_job_data_detailpage_top_category_image', 'no' );
  }
  if( isset( $_POST[ 'meta-text-back-to-listing-text' ] ) ) {
    update_post_meta( $post_id, '_job_data_back_to_listing_text', sanitize_text_field( $_POST[ 'meta-text-back-to-listing-text' ] ) );
  }
  if( isset( $_POST[ 'meta-text-apply-back-to-jobdetail-text' ] ) ) {
    update_post_meta( $post_id, '_job_apply_back_to_jobdetail_text', sanitize_text_field( $_POST[ 'meta-text-apply-back-to-jobdetail-text' ] ) );
  }

  if( isset( $_POST[ 'meta-text-jobdetail-above-content' ] ) ) {
    update_post_meta( $post_id, '_job_detail_above_content', $_POST[ 'meta-text-jobdetail-above-content' ] );
  }
  if( isset( $_POST[ 'meta-text-jobdetail-below-content' ] ) ) {
    update_post_meta( $post_id, '_job_detail_below_content', $_POST[ 'meta-text-jobdetail-below-content' ] );
  }
  if( isset( $_POST[ 'meta-text-jobdetail-sidebar-below-content' ] ) ) {
    update_post_meta( $post_id, '_job_detail_sidebar_below_content', $_POST[ 'meta-text-jobdetail-sidebar-below-content' ] );
  }

  if( isset( $_POST[ 'meta-text-referral-code-parameter' ] ) ) {
    update_post_meta( $post_id, '_job_apply_referral_code_parameter', sanitize_text_field( $_POST[ 'meta-text-referral-code-parameter' ] ) );
  }
  if( isset( $_POST[ 'meta-text-referral-api-url' ] ) ) {
    update_post_meta( $post_id, '_job_apply_referral_api_url', sanitize_text_field( $_POST[ 'meta-text-referral-api-url' ] ) );
  }
  if( isset( $_POST[ 'meta-text-referral-api-key' ] ) ) {
    update_post_meta( $post_id, '_job_apply_referral_api_key', sanitize_text_field( $_POST[ 'meta-text-referral-api-key' ] ) );
  }
  if( isset( $_POST[ 'meta-referral-tool-status' ] ) ) {
    update_post_meta( $post_id, '_job_apply_referral_tool_status', sanitize_text_field( $_POST[ 'meta-referral-tool-status' ] ) );
  }else{
    update_post_meta( $post_id, '_job_apply_referral_tool_status', 'disabled' );
  }

  if( isset( $_POST[ 'meta-text-jobalert-fname-label' ] ) ) {
    update_post_meta( $post_id, '_jobalert_form_fname_label', sanitize_text_field( $_POST[ 'meta-text-jobalert-fname-label' ] ) );
  }
  if( isset( $_POST[ 'meta-text-jobalert-lname-label' ] ) ) {
    update_post_meta( $post_id, '_jobalert_form_lname_label', sanitize_text_field( $_POST[ 'meta-text-jobalert-lname-label' ] ) );
  }
  if( isset( $_POST[ 'meta-text-jobalert-email-label' ] ) ) {
    update_post_meta( $post_id, '_jobalert_form_email_label', sanitize_text_field( $_POST[ 'meta-text-jobalert-email-label' ] ) );
  }
  if( isset( $_POST[ 'meta-text-jobalert-discipline-label' ] ) ) {
    update_post_meta( $post_id, '_jobalert_form_discipline_label', sanitize_text_field( $_POST[ 'meta-text-jobalert-discipline-label' ] ) );
  }
  if( isset( $_POST[ 'meta-text-jobalert-submit-label' ] ) ) {
    update_post_meta( $post_id, '_jobalert_form_submit_label', sanitize_text_field( $_POST[ 'meta-text-jobalert-submit-label' ] ) );
  }
  if( isset( $_POST[ 'meta-text-jobalert-above-content' ] ) ) {
    update_post_meta( $post_id, '_jobalert_form_above_content', $_POST[ 'meta-text-jobalert-above-content' ] );
  }

  if( isset( $_POST[ 'meta-text-listing-page-select' ] ) ) {
    update_post_meta( $post_id, '_listing_page_selected', sanitize_text_field( $_POST[ 'meta-text-listing-page-select' ] ) );
    
     

    if(get_option('hr_office_vacancy_shortcode_activated_pages')){
      $shortcode_activated_pages_arr = array('pageid'=>$_POST['meta-text-listing-page-select'],'shortcodeid'=>$post_id);
      $shortcode_activated_pages = get_option( 'hr_office_vacancy_shortcode_activated_pages' );
      
      if( array_search($post_id, array_column($shortcode_activated_pages, 'shortcodeid')) === false ){
        array_push($shortcode_activated_pages, $shortcode_activated_pages_arr);
        update_option( 'hr_office_vacancy_shortcode_activated_pages', $shortcode_activated_pages );
      }else{        
        foreach ($shortcode_activated_pages as $key => $slide) { 
            if (in_array($post_id, $slide)){
              $shortcode_activated_pages_arr_key = $key;
            }             
        }
        unset($shortcode_activated_pages[$shortcode_activated_pages_arr_key]);
        array_push($shortcode_activated_pages, $shortcode_activated_pages_arr);
        update_option( 'hr_office_vacancy_shortcode_activated_pages', $shortcode_activated_pages );
      }
    }else{
      $shortcode_activated_pages_arr = array(array('pageid'=>$_POST['meta-text-listing-page-select'],'shortcodeid'=>$post_id));
      add_option( 'hr_office_vacancy_shortcode_activated_pages', $shortcode_activated_pages_arr, '', 'yes' );
    }      
       

    
  }

  if(get_post_meta( $post_id, '_api_selected_filters', true )){
    $api_selected_filters = get_post_meta( $post_id, '_api_selected_filters', true );

    foreach ($api_selected_filters as $val_sall) { 
      $filter_input_name = 'meta_filter_label_'.str_replace(' ', '_', $val_sall);
      $filter_meta_key = '_api_filter_label_'.str_replace(' ', '_', $val_sall);
      if( isset( $_POST[ $filter_input_name ] ) ) {
        update_post_meta( $post_id, $filter_meta_key, sanitize_text_field( $_POST[ $filter_input_name ] ) );
      }
    } 
          
  }

  if(get_post_meta( $post_id, '_api_selected_job_detail_page_data', true )){
    $api_selected_job_detail_page_data = get_post_meta( $post_id, '_api_selected_job_detail_page_data', true );

    foreach ($api_selected_job_detail_page_data as $val_sjddall) { 
      $selected_jobdata_input_name = 'meta_job_detail_data_label_'.$val_sjddall;
      $selected_jobdata_meta_key = '_api_job_detail_data_label_'.$val_sjddall;
      if( isset( $_POST[ $selected_jobdata_input_name ] ) ) {
        update_post_meta( $post_id, $selected_jobdata_meta_key, sanitize_text_field( $_POST[ $selected_jobdata_input_name ] ) );
      }
    } 
          
  }

  if(get_post_meta( $post_id, '_api_selected_job_data', true )){
    $api_selected_job_data = get_post_meta( $post_id, '_api_selected_job_data', true );

    foreach ($api_selected_job_data as $val_sjldata) { 
      $selected_joblist_data_input_name = 'meta_job_listing_data_label_'.$val_sjldata;
      $selected_joblist_data_meta_key = '_api_job_listing_data_label_'.$val_sjldata;
      if( isset( $_POST[ $selected_joblist_data_input_name ] ) ) {
        update_post_meta( $post_id, $selected_joblist_data_meta_key, sanitize_text_field( $_POST[ $selected_joblist_data_input_name ] ) );
      }
    } 
          
  }

  if(get_post_meta( $post_id, '_api_job_data_category_list', true )){
      $api_job_data_category_list = unserialize(get_post_meta( $post_id, '_api_job_data_category_list', true ));
      $findonstring = array(" ","/");      

      foreach ($api_job_data_category_list as $val_catimg) { 
         $catimg_input_name = 'meta_jobdata_category_list_image_'.str_replace($findonstring, '_', $val_catimg);
         $catimg_meta_key = '_api_job_data_category_list_image_'.str_replace($findonstring, '_', $val_catimg);
         if( isset( $_POST[ $catimg_input_name ] ) ) {
           update_post_meta( $post_id, $catimg_meta_key, sanitize_text_field( $_POST[ $catimg_input_name ] ) );
         }
      }           
  }

  // update custom url settings
  if( isset( $_POST['nls-enable-custom-url'] ) ){
      $res_arry['nls_enable_custom_url_structure'] = 'yes';
      if( isset( $_POST['nls-select-custom-url-filter'] ) && ! empty( trim( $_POST['nls-select-custom-url-filter'] ) ) ){
         $res_arry['nls_selected_url_filter'] = sanitize_text_field( $_POST['nls-select-custom-url-filter'] );
      }
      update_post_meta( $post_id, 'nls_custom_url_settings', $res_arry );
  }else{
      $res_arry['enable'] = 'no'; 
      $res_arry['nls_selected_url_filter'] = '';
      update_post_meta( $post_id, 'nls_custom_url_settings', $res_arry );
  }

}
add_action( 'save_post', 'hr_office_vacancy_meta_save' );